summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorLuke Chen <luke.chen@mongodb.com>2021-02-15 16:30:36 +1100
committerEvergreen Agent <no-reply@evergreen.mongodb.com>2021-02-15 05:58:16 +0000
commit0c0d352b729eb94d28c478ab06a4f34f2216ba11 (patch)
treeef5b9629227ceada8e31c9b365a1623ada374bc6
parent0fc5b56b12dbdc248556fdfa9da2f44479eac699 (diff)
downloadmongo-0c0d352b729eb94d28c478ab06a4f34f2216ba11.tar.gz
Import wiredtiger: 87e004aa88066011b568709e49d209a63f0a9f97 from branch mongodb-5.0
ref: 509f9db55e..87e004aa88 for: 4.9.0 WT-7183 Sort test filenames in test coverage document WT-7202 Check for no count in assertion
-rw-r--r--src/third_party/wiredtiger/dist/test_tag.py4
-rw-r--r--src/third_party/wiredtiger/import.data2
-rw-r--r--src/third_party/wiredtiger/src/txn/txn_recover.c7
-rw-r--r--src/third_party/wiredtiger/test/test_coverage.md2
4 files changed, 9 insertions, 6 deletions
diff --git a/src/third_party/wiredtiger/import.data b/src/third_party/wiredtiger/import.data
index 9ed988c06f6..624767ea14a 100644
--- a/src/third_party/wiredtiger/import.data
+++ b/src/third_party/wiredtiger/import.data
@@ -2,5 +2,5 @@
"vendor": "wiredtiger",
"github": "wiredtiger/wiredtiger.git",
"branch": "mongodb-5.0",
- "commit": "509f9db55e5288e864564cccbb5822fe8b3c9fd3"
+ "commit": "87e004aa88066011b568709e49d209a63f0a9f97"
}
diff --git a/src/third_party/wiredtiger/src/txn/txn_recover.c b/src/third_party/wiredtiger/src/txn/txn_recover.c
index e81451a96b3..e71b686d633 100644
--- a/src/third_party/wiredtiger/src/txn/txn_recover.c
+++ b/src/third_party/wiredtiger/src/txn/txn_recover.c
@@ -506,9 +506,10 @@ __recovery_set_checkpoint_snapshot(WT_SESSION_IMPL *session)
* snapshot max.
*/
WT_ASSERT(session,
- conn->recovery_ckpt_snapshot_count == counter &&
- conn->recovery_ckpt_snapshot[0] == conn->recovery_ckpt_snap_min &&
- conn->recovery_ckpt_snapshot[counter - 1] < conn->recovery_ckpt_snap_max);
+ conn->recovery_ckpt_snapshot == NULL ||
+ (conn->recovery_ckpt_snapshot_count == counter &&
+ conn->recovery_ckpt_snapshot[0] == conn->recovery_ckpt_snap_min &&
+ conn->recovery_ckpt_snapshot[counter - 1] < conn->recovery_ckpt_snap_max));
}
err:
diff --git a/src/third_party/wiredtiger/test/test_coverage.md b/src/third_party/wiredtiger/test/test_coverage.md
index 5d14e4bf190..1b29241ff32 100644
--- a/src/third_party/wiredtiger/test/test_coverage.md
+++ b/src/third_party/wiredtiger/test/test_coverage.md
@@ -2,5 +2,5 @@
|---|---|---|---|---|
|Backup|Correctness|Full Backup|Full backup contains correct data|[../test/suite/test_backup01.py](../test/suite/test_backup01.py)
|Caching Eviction|Correctness|Written Data|Ensure that the data written out by eviction is correct after reading|[../test/suite/test_hs15.py](../test/suite/test_hs15.py)
-|Checkpoints|Correctness|Checkpoint Data|On system with a complex, concurrent workload the correct versions of data appear in checkpoints|[../test/suite/test_checkpoint03.py](../test/suite/test_checkpoint03.py), [../test/suite/test_checkpoint02.py](../test/suite/test_checkpoint02.py)
+|Checkpoints|Correctness|Checkpoint Data|On system with a complex, concurrent workload the correct versions of data appear in checkpoints|[../test/suite/test_checkpoint02.py](../test/suite/test_checkpoint02.py), [../test/suite/test_checkpoint03.py](../test/suite/test_checkpoint03.py)
|Checkpoints|Liveness|Liveness|Identify bugs and race conditions related to checkpoints that can cause deadlocks or livelocks|[../test/csuite/wt3363_checkpoint_op_races/main.c](../test/csuite/wt3363_checkpoint_op_races/main.c)
diff --git a/src/third_party/wiredtiger/dist/test_tag.py b/src/third_party/wiredtiger/dist/test_tag.py
index defa9906e1c..98b4f976aef 100644
--- a/src/third_party/wiredtiger/dist/test_tag.py
+++ b/src/third_party/wiredtiger/dist/test_tag.py
@@ -173,8 +173,10 @@ for tag in sorted_tags:
test_type = test_type.replace("_", " ").title()
testing_area = testing_area.replace("_", " ").title()
# Relative path to test file
link = ""
+ # Sort the filenames associated to the current tag
+ tagged_files[tag].sort()
for name in tagged_files[tag]:
link += "[" + name + "](" + name + "), "
# Remove the extra ", " at the end
@@ -173,8 +173,10 @@ for tag in sorted_tags:
test_type = test_type.replace("_", " ").title()
testing_area = testing_area.replace("_", " ").title()
- # Relative path to test file
+ # Relative path to test files
link = ""